@@ -14,12 +14,13 @@
 #include "str.h"
 #include "sysutil.h"
 #include "secbuf.h"
+#include "utility.h"
 
 int
 str_fileread(struct mystr* p_str, const char* p_filename, unsigned int maxsize)
 {
   int fd;
-  int retval;
+  int retval = 0;
   filesize_t size;
   char* p_sec_buf = 0;
   struct vsf_sysutil_statbuf* p_stat = 0;
@@ -41,14 +42,20 @@ str_fileread(struct mystr* p_str, const char* p_filename, unsigned int maxsize)
     vsf_secbuf_alloc(&p_sec_buf, (unsigned int) size);
 
     retval = vsf_sysutil_read_loop(fd, p_sec_buf, (unsigned int) size);
-    if (!vsf_sysutil_retval_is_error(retval) && (unsigned int) retval == size)
+    if (vsf_sysutil_retval_is_error(retval))
     {
-      str_alloc_memchunk(p_str, p_sec_buf, size);
+      goto free_out;
     }
+    else if ((unsigned int) retval != size)
+    {
+      die("read size mismatch");
+    }
+    str_alloc_memchunk(p_str, p_sec_buf, size);
   }
+free_out:
   vsf_sysutil_free(p_stat);
   vsf_secbuf_free(&p_sec_buf);
   vsf_sysutil_close(fd);
-  return 0;
+  return retval;
 }
 
