@@ -119,6 +119,10 @@ vsf_one_process_login(struct vsf_session* p_sess,
       p_sess->is_anonymous = 1;
       process_post_login(p_sess);
       break;
+    case kVSFLoginNull:
+      /* Fall through. */
+    case kVSFLoginReal:
+      /* Fall through. */
     default:
       bug("bad state in vsf_one_process_login");
       break;
@@ -129,7 +133,7 @@ int
 vsf_one_process_get_priv_data_sock(struct vsf_session* p_sess)
 {
   unsigned short port = vsf_sysutil_sockaddr_get_port(p_sess->p_port_sockaddr);
-  return vsf_privop_get_ftp_port_sock(p_sess, port);
+  return vsf_privop_get_ftp_port_sock(p_sess, port, 1);
 }
 
 void
