@@ -436,6 +436,8 @@ str_locate_chars(const struct mystr* p_str, const char* p_chars)
   unsigned int num_chars = vsf_sysutil_strlen(p_chars);
   unsigned int i = 0;
   retval.found = 0;
+  retval.char_found = 0;
+  retval.index = 0;
   for (; i < p_str->len; ++i)
   {
     unsigned int j = 0;
@@ -461,6 +463,7 @@ str_locate_text(const struct mystr* p_str, const char* p_text)
   unsigned int i;
   unsigned int text_len = vsf_sysutil_strlen(p_text);
   retval.found = 0;
+  retval.char_found = 0;
   retval.index = 0;
   if (text_len == 0 || text_len > p_str->len)
   {
@@ -487,6 +490,7 @@ str_locate_text_reverse(const struct mystr* p_str, const char* p_text)
   unsigned int i;
   unsigned int text_len = vsf_sysutil_strlen(p_text);
   retval.found = 0;
+  retval.char_found = 0;
   retval.index = 0;
   if (text_len == 0 || text_len > p_str->len)
   {
@@ -569,6 +573,20 @@ str_contains_space(const struct mystr* p_str)
   return 0;
 }
 
+int
+str_all_space(const struct mystr* p_str)
+{
+  unsigned int i;
+  for (i=0; i < p_str->len; i++)
+  {
+    if (!vsf_sysutil_isspace(p_str->p_buf[i]))
+    {
+      return 0;
+    }
+  }
+  return 1;
+}
+
 int
 str_contains_unprintable(const struct mystr* p_str)
 {
