@@ -1340,6 +1340,7 @@ vsf_sysutil_statbuf_get_perms(const struct vsf_sysutil_statbuf* p_statbuf)
     case S_IFSOCK: perms[0] = 's'; break;
     case S_IFCHR: perms[0] = 'c'; break;
     case S_IFBLK: perms[0] = 'b'; break;
+    default: break;
   }
   if (p_stat->st_mode & S_IRUSR) perms[1] = 'r';
   if (p_stat->st_mode & S_IWUSR) perms[2] = 'w';
@@ -1603,6 +1604,8 @@ vsf_sysutil_get_error(void)
     case ENOENT:
       retval = kVSFSysUtilErrNOENT;
       break;
+    default:
+      break;
   }
   return retval;
 }
@@ -1704,10 +1707,14 @@ vsf_sysutil_accept_timeout(int fd, struct vsf_sysutil_sockaddr* p_sockaddr,
       retval = select(fd + 1, &accept_fdset, NULL, NULL, &timeout);
       saved_errno = errno;
       vsf_sysutil_check_pending_actions(kVSFSysUtilUnknown, 0, 0);
-    } while (retval < 0 && saved_errno == EINTR);
-    if (retval == 0)
+    }
+    while (retval < 0 && saved_errno == EINTR);
+    if (retval <= 0)
     {
-      errno = EAGAIN;
+      if (retval == 0)
+      {
+        errno = EAGAIN;
+      }
       return -1;
     }
   }
@@ -1785,10 +1792,13 @@ vsf_sysutil_connect_timeout(int fd, const struct vsf_sysutil_sockaddr* p_addr,
       vsf_sysutil_check_pending_actions(kVSFSysUtilUnknown, 0, 0);
     }
     while (retval < 0 && saved_errno == EINTR);
-    if (retval == 0)
+    if (retval <= 0)
     {
+      if (retval == 0)
+      {
+        errno = EAGAIN;
+      }
       retval = -1;
-      errno = EAGAIN;
     }
     else
     {
@@ -1798,6 +1808,11 @@ vsf_sysutil_connect_timeout(int fd, const struct vsf_sysutil_sockaddr* p_addr,
       {
         die("getsockopt");
       }
+      if (retval != 0)
+      {
+        errno = retval;
+        retval = -1;
+      }
     }
   }
   if (wait_seconds > 0)
@@ -2584,6 +2599,19 @@ vsf_sysutil_tzset(void)
       s_timezone *= -1;
     }
   }
+  /* Call in to the time subsystem again now that TZ is set, trying to force
+   * caching of the actual zoneinfo for the timezone.
+   */
+  p_tm = localtime(&the_time);
+  if (p_tm == NULL)
+  {
+    die("localtime #2");
+  }
+  p_tm = gmtime(&the_time);
+  if (p_tm == NULL)
+  {
+    die("gmtime");
+  }
 }
 
 const char*
